==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/RecordFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RecordFluent<A extends RecordFluent<A>> extends BaseFluent<A>{
  public RecordFluent() {
  }
  public RecordFluent(Record instance) {
    instance = (instance != null ? instance : new Record());

    if (instance != null) {
      this.withId(instance.getId());
      this.withPhase(instance.getPhase());
      this.withSelectorKey(instance.getSelectorKey());
      this.withId(instance.getId());
      this.withPhase(instance.getPhase());
      this.withSelectorKey(instance.getSelectorKey());
    }
  }
  private String id;
  private String phase;
  private String selectorKey;
  public String getId() {
    return this.id;
  }
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  public boolean hasId() {
    return this.id != null;
  }
  public String getPhase() {
    return this.phase;
  }
  public A withPhase(String phase) {
    this.phase=phase; return (A) this;
  }
  public boolean hasPhase() {
    return this.phase != null;
  }
  public String getSelectorKey() {
    return this.selectorKey;
  }
  public A withSelectorKey(String selectorKey) {
    this.selectorKey=selectorKey; return (A) this;
  }
  public boolean hasSelectorKey() {
    return this.selectorKey != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RecordFluent that = (RecordFluent) o;
    if (!java.util.Objects.equals(id, that.id)) return false;

    if (!java.util.Objects.equals(phase, that.phase)) return false;

    if (!java.util.Objects.equals(selectorKey, that.selectorKey)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(id,  phase,  selectorKey,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (selectorKey != null) { sb.append("selectorKey:"); sb.append(selectorKey); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/RecordFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RecordFluent<A extends RecordFluent<A>> extends BaseFluent<A>{
  public RecordFluent() {
  }
  
  public RecordFluent(Record instance) {
    this.copyInstance(instance);
  }
  private String id;
  private String phase;
  private String selectorKey;
  
  protected void copyInstance(Record instance) {
    instance = (instance != null ? instance : new Record());
  
    if (instance != null) {
        this.withId(instance.getId());
        this.withPhase(instance.getPhase());
        this.withSelectorKey(instance.getSelectorKey());
        this.withId(instance.getId());
        this.withPhase(instance.getPhase());
        this.withSelectorKey(instance.getSelectorKey());
      }
  }
  
  public String getId() {
    return this.id;
  }
  
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  
  public boolean hasId() {
    return this.id != null;
  }
  
  public String getPhase() {
    return this.phase;
  }
  
  public A withPhase(String phase) {
    this.phase=phase; return (A) this;
  }
  
  public boolean hasPhase() {
    return this.phase != null;
  }
  
  public String getSelectorKey() {
    return this.selectorKey;
  }
  
  public A withSelectorKey(String selectorKey) {
    this.selectorKey=selectorKey; return (A) this;
  }
  
  public boolean hasSelectorKey() {
    return this.selectorKey != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RecordFluent that = (RecordFluent) o;
    if (!java.util.Objects.equals(id, that.id)) return false;
  
    if (!java.util.Objects.equals(phase, that.phase)) return false;
  
    if (!java.util.Objects.equals(selectorKey, that.selectorKey)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(id,  phase,  selectorKey,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (selectorKey != null) { sb.append("selectorKey:"); sb.append(selectorKey); }
    sb.append("}");
    return sb.toString();
  }
  

}
